[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) 
[![PyPI version](https://badge.fury.io/py/tpi-connector.svg)](https://pypi.org/project/xialib-gcs) 
# Restful connector to tpi-compliance applications
